#undef strlcat
size_t strlcat(char *, const char *, size_t);
#undef strlcpy
size_t strlcpy(char *, const char *, size_t);
#undef reallocarray
void *reallocarray(void *, size_t, size_t);
